@@ -4,7 +4,7 @@ from uuid import uuid4
 import atexit
 import os
 
-from pokeman import heapq as _heapq_
+from pokeman.amqp_resources import heapq as _heapq_
 from pokeman.composite.connection import Connection, SelectConnection
 from pokeman.coatings.ptypes import Ptypes
 from pokeman.coatings.builders import Foreman
